@@ -11,7 +11,7 @@ class ITEUI(EditorMain):
 
     def __init__(self, use_theme=None, debug=False, **kwargs):
         super().__init__(use_theme, debug, **kwargs)
-        self.program_buffer = 1024000
+        self.program_buffer: int = 1024000
         self.main_window.title("ITE")
         content_init(self)
         build_ite_menu(self)
